pub enum DampingSchedule {
Fixed(f64),
Linear {
start: f64,
end: f64,
total_steps: usize,
},
Exponential {
initial: f64,
decay: f64,
},
Adaptive {
base: f64,
increase_rate: f64,
decrease_rate: f64,
},
}Expand description
Damping schedule types for controlling how damping evolves over iterations.
Variants
Fixed(f64)
Fixed damping throughout all iterations.
Linear
Linear interpolation from start to end over total_steps.
Fields
Exponential
Exponential decay: initial * decay^iteration.
Adaptive
Increase damping when residual grows, decrease when stable.
Implementations
Sourceimpl DampingSchedule
impl DampingSchedule
Sourcepub fn get_damping(
&self,
iteration: usize,
prev_residual: Option<f64>,
curr_residual: Option<f64>,
current_damping: f64,
) -> f64
pub fn get_damping( &self, iteration: usize, prev_residual: Option<f64>, curr_residual: Option<f64>, current_damping: f64, ) -> f64
Get damping factor for a given iteration and optional residual information.
Arguments
iteration- Current iteration numberprev_residual- Residual from the previous iteration (if available)curr_residual- Residual from the current iteration (if available)current_damping- The current damping factor (used by adaptive schedule)