pub struct ConvergenceState {
pub iteration: usize,
pub converged: bool,
pub diverged: bool,
pub residual_history: Vec<f64>,
pub damping_history: Vec<f64>,
pub consecutive_converged: usize,
}Expand description
Current state of convergence tracking.
Fields
iteration: usizeCurrent iteration count.
converged: boolWhether the algorithm has converged.
diverged: boolWhether the algorithm has diverged.
residual_history: Vec<f64>History of residual values per iteration.
damping_history: Vec<f64>History of damping values per iteration.
consecutive_converged: usizeNumber of consecutive iterations below tolerance.
Implementations
Sourceimpl ConvergenceState
impl ConvergenceState
Sourcepub fn latest_residual(&self) -> Option<f64>
pub fn latest_residual(&self) -> Option<f64>
Return the most recent residual value, if any.
Sourcepub fn convergence_rate(&self) -> Option<f64>
pub fn convergence_rate(&self) -> Option<f64>
Compute the convergence rate as the ratio of the last two residuals.
Returns None if fewer than two residuals have been recorded.