pub fn render_dot(model: &FactorGraphModel) -> StringExpand description
Render a FactorGraphModel as a DOT (Graphviz) graph.
The output uses the undirected graph keyword because factor graphs
are inherently undirected.
pub fn render_dot(model: &FactorGraphModel) -> StringRender a FactorGraphModel as a DOT (Graphviz) graph.
The output uses the undirected graph keyword because factor graphs
are inherently undirected.