pub enum UpdateSchedule {
Synchronous,
Sequential,
Residual,
}Expand description
Order in which messages are updated each sweep.
Variants
Synchronous
All messages updated in parallel (synchronous / flood schedule).
The new round of messages is computed from the previous round. Classic Loopy BP.
Sequential
Messages updated one by one in a fixed round-robin order.
More stable but potentially slower to converge.
Residual
Residual BP — at each step update the message with the largest current L∞ residual first.
Often converges in fewer sweeps than synchronous or sequential schedules on highly loopy graphs.