pub struct BetheFreeEnergy {
pub factor_energy: f64,
pub variable_entropy: f64,
pub total: f64,
pub log_z: f64,
}Expand description
Bethe free energy components.
The Bethe approximation decomposes the global free energy into single-variable and factor contributions. At the fixed point of LBP, the Bethe free energy equals the variational free energy under the Bethe approximation to the belief propagation.
Fields
factor_energy: f64Factor-node energy term: ∑a ∑{x_a} b_a(x_a) ln[φ_a(x_a) / b_a(x_a)]
variable_entropy: f64Variable-node entropy term: (1 - d_i) ∑i ∑{x_i} b_i(x_i) ln b_i(x_i)
total: f64Total Bethe free energy = factor_energy + variable_entropy.
log_z: f64Approximate log-partition function: -F_Bethe.