pub struct HiddenMarkovModel { /* private fields */ }Expand description
Hidden Markov Model builder.
A temporal model with hidden states and observations.
Implementations
Sourceimpl HiddenMarkovModel
impl HiddenMarkovModel
Sourcepub fn new(
num_states: usize,
num_observations: usize,
time_steps: usize,
) -> Self
pub fn new( num_states: usize, num_observations: usize, time_steps: usize, ) -> Self
Create a new HMM.
Arguments
num_states- Number of hidden statesnum_observations- Number of observable symbolstime_steps- Length of sequence
Sourcepub fn set_initial_distribution(
&mut self,
initial: ArrayD<f64>,
) -> Result<&mut Self>
pub fn set_initial_distribution( &mut self, initial: ArrayD<f64>, ) -> Result<&mut Self>
Set initial state distribution P(state_0).
Sourcepub fn set_transition_matrix(
&mut self,
transition: ArrayD<f64>,
) -> Result<&mut Self>
pub fn set_transition_matrix( &mut self, transition: ArrayD<f64>, ) -> Result<&mut Self>
Set transition matrix P(state_t | state_{t-1}).
Arguments
transition- Transition probabilities [from_state, to_state]
Sourcepub fn set_emission_matrix(
&mut self,
emission: ArrayD<f64>,
) -> Result<&mut Self>
pub fn set_emission_matrix( &mut self, emission: ArrayD<f64>, ) -> Result<&mut Self>
Set emission matrix P(obs_t | state_t).
Arguments
emission- Emission probabilities [state, observation]
Sourcepub fn graph(&self) -> &FactorGraph
pub fn graph(&self) -> &FactorGraph
Get the underlying factor graph.
Sourcepub fn filter(&self, observations: &[usize], t: usize) -> Result<ArrayD<f64>>
pub fn filter(&self, observations: &[usize], t: usize) -> Result<ArrayD<f64>>
Perform filtering: compute P(state_t | obs_0:t).
Uses variable elimination to compute the marginal distribution over the hidden state at time t given observations from 0 to t.