pub struct VmpConfig {
pub states: HashMap<String, VariationalState>,
pub factors: Vec<VmpFactor>,
pub max_iterations: usize,
pub tolerance: f64,
pub divergence_tolerance: f64,
}Expand description
User-facing configuration describing a VMP problem.
Fields
states: HashMap<String, VariationalState>Per-variable variational state.
factors: Vec<VmpFactor>Factors (conjugate relationships).
max_iterations: usizeMaximum iterations.
tolerance: f64Convergence tolerance on both ELBO change and the max L∞ residual.
divergence_tolerance: f64Maximum allowed ELBO decrease before the engine bails out with a
ConvergenceFailure error (guards against numerical divergence).
Implementations
Sourceimpl VmpConfig
impl VmpConfig
Sourcepub fn with_gaussian(
self,
name: &str,
prior_mean: f64,
precision: f64,
) -> Result<Self>
pub fn with_gaussian( self, name: &str, prior_mean: f64, precision: f64, ) -> Result<Self>
Register a Gaussian variable with a prior N(prior_mean, 1/precision).
Sourcepub fn with_categorical(self, name: &str, num_categories: usize) -> Result<Self>
pub fn with_categorical(self, name: &str, num_categories: usize) -> Result<Self>
Register a Categorical variable with a flat prior over k categories.
Sourcepub fn with_dirichlet(self, name: &str, concentration: Vec<f64>) -> Result<Self>
pub fn with_dirichlet(self, name: &str, concentration: Vec<f64>) -> Result<Self>
Register a Dirichlet variable with prior concentration α.
Sourcepub fn with_factor(self, factor: VmpFactor) -> Self
pub fn with_factor(self, factor: VmpFactor) -> Self
Append a VMP factor.
Sourcepub fn with_limits(self, max_iterations: usize, tolerance: f64) -> Self
pub fn with_limits(self, max_iterations: usize, tolerance: f64) -> Self
Override the max iterations / tolerance pair.