pub enum MessageDirection {
FactorToVariable,
VariableToFactor,
}Expand description
Direction of a VMP message.
Variants
FactorToVariable
A factor sending an update to one of its variable neighbours.
VariableToFactor
A variable sending its expected sufficient statistics to an adjacent factor.